==> blesta-5.10.2.zip: blesta/plugins/domains/language/id_id/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.edit.text_registration_date'] = 'Tanggal Terdaftar:';
$lang['AdminMain.index.text_date_added'] = 'Tanggal Ditambahkan:';
$lang['AdminMain.index.heading_dateregistration'] = 'Tanggal Terdaftar';
$lang['AdminMain.index.heading_registrar'] = 'Panitera';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Registrar domain telah diperbarui!';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domain:';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Pilih Secara Otomatis --';
$lang['AdminMain.edit.title_basic_options'] = 'Opsi Dasar';
$lang['AdminMain.edit.title_actions'] = 'Tindakan';
$lang['AdminMain.edit.title_domain_information'] = 'Informasi Domain';
$lang['AdminMain.edit.term_years'] = '%1$s Tahun';
$lang['AdminMain.edit.term_year'] = 'Tahun %1$s';
$lang['AdminMain.edit.term_months'] = '%1 $ s Bulan';
$lang['AdminMain.edit.term_month'] = '%1 $s Bulan';
$lang['AdminMain.edit.term_weeks'] = '%1$s Minggu';
$lang['AdminMain.edit.term_week'] = '%1 $s Minggu';
$lang['AdminMain.edit.term_days'] = '%1 $ s Hari';
$lang['AdminMain.edit.term_day'] = '%1$s Day';
$lang['AdminMain.edit.text_date_canceled'] = 'Tanggal Pembatalan:';
$lang['AdminMain.edit.text_date_suspended'] = 'Tanggal Penangguhan:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Tanggal Terakhir Diperbaharui:';
$lang['AdminMain.edit.text_never'] = 'Tidak pernah.';
$lang['AdminMain.edit.text_date_expires'] = 'Tanggal Berakhir:';
$lang['AdminMain.edit.text_date_renews'] = 'Memperbarui Tanggal:';
$lang['AdminMain.edit.text_date_added'] = 'Tanggal Dibuat:';
$lang['AdminMain.edit.text_status'] = 'Status:';
$lang['AdminMain.edit.text_years'] = 'Tahun Terdaftar:';
$lang['AdminMain.edit.text_registrar'] = 'Panitera:';
$lang['AdminMain.edit.text_domain'] = 'Domain:';
$lang['AdminMain.edit.field_edit_service'] = 'Layanan Edit';
$lang['AdminMain.edit.field_activate'] = 'Aktifkan';
$lang['AdminMain.edit.field_submit'] = 'Memperbarui';
$lang['AdminMain.edit.field_notify_order'] = 'Kirim email konfirmasi pesanan saat diaktifkan';
$lang['AdminMain.edit.field_use_module'] = 'Gunakan modul';
$lang['AdminMain.edit.field_module'] = 'Modul Pendaftar';
$lang['AdminMain.edit.field_client'] = 'Klien';
$lang['AdminMain.edit.field_ns5'] = 'Server Nama 5';
$lang['AdminMain.edit.field_ns4'] = 'Server Nama 4';
$lang['AdminMain.edit.field_ns3'] = 'Server Nama 3';
$lang['AdminMain.edit.field_ns2'] = 'Server Nama 2';
$lang['AdminMain.edit.field_ns1'] = 'Server Nama 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Mengaktifkan Pembaruan Otomatis';
$lang['AdminMain.edit.field_years'] = 'Tahun';
$lang['AdminMain.edit.field_action'] = 'Tindakan';
$lang['AdminMain.edit.link_viewclient'] = 'Lihat Klien';
$lang['AdminMain.edit.boxtitle_edit'] = 'Edit Domain: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Klien #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Diskon:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Sub Total:';
$lang['AdminMain.add_confirmation.price'] = 'Harga';
$lang['AdminMain.add_confirmation.qty'] = 'Kuantitas';
$lang['AdminMain.add_confirmation.description'] = 'Deskripsi';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Transfer';
$lang['AdminMain.add_confirmation.type_register'] = 'Pendaftaran';
$lang['AdminMain.add_confirmation.field_edit'] = 'Sunting';
$lang['AdminMain.add_confirmation.field_add'] = 'Tambahkan Domain';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Memperbarui';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Kode Kupon';
$lang['AdminMain.add_confirmation.field_price'] = 'Harga:';
$lang['AdminMain.add_confirmation.field_type'] = 'Ketik:';
$lang['AdminMain.add_confirmation.field_years'] = 'Tahun:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Tidak.';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Ya.';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Kirim Email Konfirmasi Pesanan:';
$lang['AdminMain.add_confirmation.field_module'] = 'Modul Pendaftar:';
$lang['AdminMain.add_confirmation.field_status'] = 'Status:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Jangan Buat Faktur';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Tambahkan ke Faktur %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Buat Faktur Baru';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Metode Faktur:';
$lang['AdminMain.add.edit_package_pricing'] = 'Edit Harga';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (memperbaharui @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Pesanan Dipilih';
$lang['AdminMain.add.term_years'] = '%1$s Tahun';
$lang['AdminMain.add.term_year'] = 'Tahun %1$s';
$lang['AdminMain.add.term_months'] = '%1 $ s Bulan';
$lang['AdminMain.add.term_month'] = '%1 $s Bulan';
$lang['AdminMain.add.term_weeks'] = '%1$s Minggu';
$lang['AdminMain.add.term_week'] = '%1 $s Minggu';
$lang['AdminMain.add.term_days'] = '%1 $ s Hari';
$lang['AdminMain.add.term_day'] = '%1$s Day';
$lang['AdminMain.add.text_domain_unavailable'] = 'Tidak tersedia';
$lang['AdminMain.add.text_domain_available'] = 'Tersedia';
$lang['AdminMain.add.heading_options'] = 'Pilihan';
$lang['AdminMain.add.heading_status'] = 'Status';
$lang['AdminMain.add.heading_domain'] = 'Domain';
$lang['AdminMain.add.title_registrar_options'] = 'Opsi Pendaftar';
$lang['AdminMain.add.title_basic_options'] = 'Opsi Dasar';
$lang['AdminMain.add.title_search_results'] = 'Hasil Pencarian';
$lang['AdminMain.add.field_notify_order'] = 'Kirim email konfirmasi pesanan saat diaktifkan';
$lang['AdminMain.add.field_use_module'] = 'Penyediaan domain menggunakan modul registrar saat diaktifkan';
$lang['AdminMain.add.field_module'] = 'Modul Pendaftar';
$lang['AdminMain.add.field_status'] = 'Status';
$lang['AdminMain.add.field_years'] = 'Tahun';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Jangan Buat Faktur';
$lang['AdminMain.add.field_invoice_method_append'] = 'Tambahkan ke Faktur yang Sudah Ada';
$lang['AdminMain.add.field_invoice_method_create'] = 'Buat Faktur Baru';
$lang['AdminMain.add.field_invoice_method'] = 'Metode Faktur';
$lang['AdminMain.add.field_submit'] = 'Lanjutkan';
$lang['AdminMain.add.field_lookup'] = 'Periksa Ketersediaan';
$lang['AdminMain.add.field_add'] = 'Tambahkan Domain';
$lang['AdminMain.add.field_register'] = 'Daftar';
$lang['AdminMain.add.field_transfer'] = 'Transfer';
$lang['AdminMain.add.link_viewclient'] = 'Lihat Klien';
$lang['AdminMain.add.boxtitle_add'] = 'Tambahkan Domain: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Klien #%1$s';
$lang['AdminMain.index.unparent'] = 'Harga Tidak Jelas dan Atur Ulang';
$lang['AdminMain.!error.unsupported_domain'] = 'Nama domain tidak didukung.';
$lang['AdminMain.!success.service_edited'] = 'Domain telah berhasil diperbarui!';
$lang['AdminMain.!success.domain_add'] = 'Domain telah berhasil ditambahkan!';
$lang['AdminMain.!success.domain_transfer'] = 'Domain telah berhasil ditransfer!';
$lang['AdminMain.!success.domain_register'] = 'Domain telah berhasil didaftarkan!';
$lang['AdminMain.!success.domains_unparented'] = 'Domain yang dipilih telah dihapus dari layanan induknya dan harganya telah berhasil disetel ulang!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nama Domain';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Apa saja';
$lang['AdminMain.domains.action.field_client'] = 'Klien';
$lang['AdminMain.domains.action.field_nameservers'] = 'Pelayan nama';
$lang['AdminMain.domains.action.field_years'] = 'Tahun';
$lang['AdminMain.index.field_actionsubmit'] = 'Kirim';
$lang['AdminMain.index.domain_push_to_client'] = 'Dorong ke Klien';
$lang['AdminMain.index.update_nameservers'] = 'Perbarui Server Nama';
$lang['AdminMain.index.domain_renewal'] = 'Perpanjang Domain';
$lang['AdminMain.index.change_auto_renewal'] = 'Ubah Perpanjangan Otomatis';
$lang['AdminMain.index.text_off'] = 'Mati';
$lang['AdminMain.index.text_on'] = 'Pada';
$lang['AdminMain.index.text_never'] = 'Tidak pernah';
$lang['AdminMain.index.no_results'] = 'Tidak ada layanan dengan status ini.';
$lang['AdminMain.index.confirm_delete'] = 'Apakah Anda yakin ingin menghapus layanan ini?';
$lang['AdminMain.index.option_delete'] = 'Menghapus';
$lang['AdminMain.index.option_manage'] = 'Mengelola';
$lang['AdminMain.index.option_parent'] = 'Orang tua';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Domain Baru';
$lang['AdminMain.index.category_canceled'] = 'Dibatalkan';
$lang['AdminMain.index.category_suspended'] = 'Ditangguhkan';
$lang['AdminMain.index.category_pending'] = 'Tertunda';
$lang['AdminMain.index.category_active'] = 'Aktif';
$lang['AdminMain.index.heading_options'] = 'Pilihan';
$lang['AdminMain.index.heading_datecanceled'] = 'Tanggal Dibatalkan';
$lang['AdminMain.index.heading_datesuspended'] = 'Tanggal Ditangguhkan';
$lang['AdminMain.index.heading_dateexpires'] = 'Tanggal Berakhir';
$lang['AdminMain.index.heading_daterenews'] = 'Pembaruan Tanggal';
$lang['AdminMain.index.heading_datecreated'] = 'Tanggal Dibuat';
$lang['AdminMain.index.heading_term'] = 'Istilah';
$lang['AdminMain.index.heading_domain'] = 'Domain';
$lang['AdminMain.index.heading_status'] = 'Status';
$lang['AdminMain.index.heading_addons'] = 'Pengaya';
$lang['AdminMain.index.boxtitle_domains'] = 'Domain';
$lang['AdminMain.index.page_title'] = 'Domain Klien #%1$s';
$lang['AdminMain.!success.domains_pushed'] = 'Domain yang dipilih berhasil didorong ke klien baru.';
$lang['AdminMain.!success.update_nameservers'] = 'Server nama domain telah diperbarui!';
$lang['AdminMain.!success.domain_renewal'] = 'Domain telah diperbarui!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Pembaruan otomatis Domain telah diperbarui!';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/id_id/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.edit.text_registration_date'] = 'Tanggal Terdaftar:';
$lang['AdminMain.index.text_date_added'] = 'Tanggal Ditambahkan:';
$lang['AdminMain.index.heading_dateregistration'] = 'Tanggal Terdaftar';
$lang['AdminMain.index.heading_registrar'] = 'Panitera';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Registrar domain telah diperbarui!';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domain:';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Pilih Secara Otomatis --';
$lang['AdminMain.edit.title_basic_options'] = 'Opsi Dasar';
$lang['AdminMain.edit.title_actions'] = 'Tindakan';
$lang['AdminMain.edit.title_domain_information'] = 'Informasi Domain';
$lang['AdminMain.edit.term_years'] = '%1$s Tahun';
$lang['AdminMain.edit.term_year'] = 'Tahun %1$s';
$lang['AdminMain.edit.term_months'] = '%1 $ s Bulan';
$lang['AdminMain.edit.term_month'] = '%1 $s Bulan';
$lang['AdminMain.edit.term_weeks'] = '%1$s Minggu';
$lang['AdminMain.edit.term_week'] = '%1 $s Minggu';
$lang['AdminMain.edit.term_days'] = '%1 $ s Hari';
$lang['AdminMain.edit.term_day'] = '%1$s Day';
$lang['AdminMain.edit.text_date_canceled'] = 'Tanggal Pembatalan:';
$lang['AdminMain.edit.text_date_suspended'] = 'Tanggal Penangguhan:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Tanggal Terakhir Diperbaharui:';
$lang['AdminMain.edit.text_never'] = 'Tidak pernah.';
$lang['AdminMain.edit.text_date_expires'] = 'Tanggal Berakhir:';
$lang['AdminMain.edit.text_date_renews'] = 'Memperbarui Tanggal:';
$lang['AdminMain.edit.text_date_added'] = 'Tanggal Dibuat:';
$lang['AdminMain.edit.text_status'] = 'Status:';
$lang['AdminMain.edit.text_years'] = 'Tahun Terdaftar:';
$lang['AdminMain.edit.text_registrar'] = 'Panitera:';
$lang['AdminMain.edit.text_domain'] = 'Domain:';
$lang['AdminMain.edit.field_edit_service'] = 'Layanan Edit';
$lang['AdminMain.edit.field_activate'] = 'Aktifkan';
$lang['AdminMain.edit.field_submit'] = 'Memperbarui';
$lang['AdminMain.edit.field_notify_order'] = 'Kirim email konfirmasi pesanan saat diaktifkan';
$lang['AdminMain.edit.field_use_module'] = 'Gunakan modul';
$lang['AdminMain.edit.field_module'] = 'Modul Pendaftar';
$lang['AdminMain.edit.field_client'] = 'Klien';
$lang['AdminMain.edit.field_ns5'] = 'Server Nama 5';
$lang['AdminMain.edit.field_ns4'] = 'Server Nama 4';
$lang['AdminMain.edit.field_ns3'] = 'Server Nama 3';
$lang['AdminMain.edit.field_ns2'] = 'Server Nama 2';
$lang['AdminMain.edit.field_ns1'] = 'Server Nama 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Mengaktifkan Pembaruan Otomatis';
$lang['AdminMain.edit.field_years'] = 'Tahun';
$lang['AdminMain.edit.field_action'] = 'Tindakan';
$lang['AdminMain.edit.link_viewclient'] = 'Lihat Klien';
$lang['AdminMain.edit.boxtitle_edit'] = 'Edit Domain: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Klien #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Diskon:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Sub Total:';
$lang['AdminMain.add_confirmation.price'] = 'Harga';
$lang['AdminMain.add_confirmation.qty'] = 'Kuantitas';
$lang['AdminMain.add_confirmation.description'] = 'Deskripsi';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Transfer';
$lang['AdminMain.add_confirmation.type_register'] = 'Pendaftaran';
$lang['AdminMain.add_confirmation.field_edit'] = 'Sunting';
$lang['AdminMain.add_confirmation.field_add'] = 'Tambahkan Domain';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Memperbarui';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Kode Kupon';
$lang['AdminMain.add_confirmation.field_price'] = 'Harga:';
$lang['AdminMain.add_confirmation.field_type'] = 'Ketik:';
$lang['AdminMain.add_confirmation.field_years'] = 'Tahun:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Tidak.';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Ya.';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Kirim Email Konfirmasi Pesanan:';
$lang['AdminMain.add_confirmation.field_module'] = 'Modul Pendaftar:';
$lang['AdminMain.add_confirmation.field_status'] = 'Status:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Jangan Buat Faktur';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Tambahkan ke Faktur %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Buat Faktur Baru';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Metode Faktur:';
$lang['AdminMain.add.edit_package_pricing'] = 'Edit Harga';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (memperbaharui @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Pesanan Dipilih';
$lang['AdminMain.add.term_years'] = '%1$s Tahun';
$lang['AdminMain.add.term_year'] = 'Tahun %1$s';
$lang['AdminMain.add.term_months'] = '%1 $ s Bulan';
$lang['AdminMain.add.term_month'] = '%1 $s Bulan';
$lang['AdminMain.add.term_weeks'] = '%1$s Minggu';
$lang['AdminMain.add.term_week'] = '%1 $s Minggu';
$lang['AdminMain.add.term_days'] = '%1 $ s Hari';
$lang['AdminMain.add.term_day'] = '%1$s Day';
$lang['AdminMain.add.text_domain_unavailable'] = 'Tidak tersedia';
$lang['AdminMain.add.text_domain_available'] = 'Tersedia';
$lang['AdminMain.add.heading_options'] = 'Pilihan';
$lang['AdminMain.add.heading_status'] = 'Status';
$lang['AdminMain.add.heading_domain'] = 'Domain';
$lang['AdminMain.add.title_registrar_options'] = 'Opsi Pendaftar';
$lang['AdminMain.add.title_basic_options'] = 'Opsi Dasar';
$lang['AdminMain.add.title_search_results'] = 'Hasil Pencarian';
$lang['AdminMain.add.field_notify_order'] = 'Kirim email konfirmasi pesanan saat diaktifkan';
$lang['AdminMain.add.field_use_module'] = 'Penyediaan domain menggunakan modul registrar saat diaktifkan';
$lang['AdminMain.add.field_module'] = 'Modul Pendaftar';
$lang['AdminMain.add.field_status'] = 'Status';
$lang['AdminMain.add.field_years'] = 'Tahun';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Jangan Buat Faktur';
$lang['AdminMain.add.field_invoice_method_append'] = 'Tambahkan ke Faktur yang Sudah Ada';
$lang['AdminMain.add.field_invoice_method_create'] = 'Buat Faktur Baru';
$lang['AdminMain.add.field_invoice_method'] = 'Metode Faktur';
$lang['AdminMain.add.field_submit'] = 'Lanjutkan';
$lang['AdminMain.add.field_lookup'] = 'Periksa Ketersediaan';
$lang['AdminMain.add.field_add'] = 'Tambahkan Domain';
$lang['AdminMain.add.field_register'] = 'Daftar';
$lang['AdminMain.add.field_transfer'] = 'Transfer';
$lang['AdminMain.add.link_viewclient'] = 'Lihat Klien';
$lang['AdminMain.add.boxtitle_add'] = 'Tambahkan Domain: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Klien #%1$s';
$lang['AdminMain.index.unparent'] = 'Harga Tidak Jelas dan Atur Ulang';
$lang['AdminMain.!error.unsupported_domain'] = 'Nama domain tidak didukung.';
$lang['AdminMain.!success.service_edited'] = 'Domain telah berhasil diperbarui!';
$lang['AdminMain.!success.domain_add'] = 'Domain telah berhasil ditambahkan!';
$lang['AdminMain.!success.domain_transfer'] = 'Domain telah berhasil ditransfer!';
$lang['AdminMain.!success.domain_register'] = 'Domain telah berhasil didaftarkan!';
$lang['AdminMain.!success.domains_unparented'] = 'Domain yang dipilih telah dihapus dari layanan induknya dan harganya telah berhasil disetel ulang!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nama Domain';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Apa saja';
$lang['AdminMain.domains.action.field_client'] = 'Klien';
$lang['AdminMain.domains.action.field_nameservers'] = 'Pelayan nama';
$lang['AdminMain.domains.action.field_years'] = 'Tahun';
$lang['AdminMain.index.field_actionsubmit'] = 'Kirim';
$lang['AdminMain.index.domain_push_to_client'] = 'Dorong ke Klien';
$lang['AdminMain.index.update_nameservers'] = 'Perbarui Server Nama';
$lang['AdminMain.index.domain_renewal'] = 'Perpanjang Domain';
$lang['AdminMain.index.change_auto_renewal'] = 'Ubah Perpanjangan Otomatis';
$lang['AdminMain.index.text_off'] = 'Mati';
$lang['AdminMain.index.text_on'] = 'Pada';
$lang['AdminMain.index.text_never'] = 'Tidak pernah';
$lang['AdminMain.index.no_results'] = 'Tidak ada layanan dengan status ini.';
$lang['AdminMain.index.confirm_delete'] = 'Apakah Anda yakin ingin menghapus layanan ini?';
$lang['AdminMain.index.option_delete'] = 'Menghapus';
$lang['AdminMain.index.option_manage'] = 'Mengelola';
$lang['AdminMain.index.option_parent'] = 'Orang tua';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Domain Baru';
$lang['AdminMain.index.category_canceled'] = 'Dibatalkan';
$lang['AdminMain.index.category_suspended'] = 'Ditangguhkan';
$lang['AdminMain.index.category_pending'] = 'Tertunda';
$lang['AdminMain.index.category_active'] = 'Aktif';
$lang['AdminMain.index.heading_options'] = 'Pilihan';
$lang['AdminMain.index.heading_datecanceled'] = 'Tanggal Dibatalkan';
$lang['AdminMain.index.heading_datesuspended'] = 'Tanggal Ditangguhkan';
$lang['AdminMain.index.heading_dateexpires'] = 'Tanggal Berakhir';
$lang['AdminMain.index.heading_daterenews'] = 'Pembaruan Tanggal';
$lang['AdminMain.index.heading_datecreated'] = 'Tanggal Dibuat';
$lang['AdminMain.index.heading_term'] = 'Istilah';
$lang['AdminMain.index.heading_domain'] = 'Domain';
$lang['AdminMain.index.heading_status'] = 'Status';
$lang['AdminMain.index.heading_addons'] = 'Pengaya';
$lang['AdminMain.index.boxtitle_domains'] = 'Domain';
$lang['AdminMain.index.page_title'] = 'Domain Klien #%1$s';
$lang['AdminMain.!success.domains_pushed'] = 'Domain yang dipilih berhasil didorong ke klien baru.';
$lang['AdminMain.!success.update_nameservers'] = 'Server nama domain telah diperbarui!';
$lang['AdminMain.!success.domain_renewal'] = 'Domain telah diperbarui!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Pembaruan otomatis Domain telah diperbarui!';
$lang['AdminMain.edit.field_registration_date'] = 'Ubah Tanggal Pendaftaran';
$lang['AdminMain.edit.field_expiration_date'] = 'Ubah Tanggal Kedaluwarsa';
$lang['AdminMain.!success.change_registration_date'] = 'Tanggal pendaftaran Domain telah diperbarui!';
$lang['AdminMain.!success.change_expiration_date'] = 'Tanggal kedaluwarsa Domain telah diperbarui!';
